==> koha-17.05.04.tar.gz: koha-17.05.04/tools/upload.pl <==
#!/usr/bin/perl

# This file is part of Koha.
#
# Copyright (C) 2015 Rijksmuseum
#
# Koha is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# Koha is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Koha; if not, see <http://www.gnu.org/licenses>.

use Modern::Perl;
use CGI qw/-utf8/;
use JSON;

use C4::Auth;
use C4::Output;
use Koha::UploadedFiles;

my $input  = CGI::->new;
my $op     = $input->param('op') // 'new';
my $plugin = $input->param('plugin');
my $index  = $input->param('index');         # MARC editor input field id
my $term   = $input->param('term');
my $id     = $input->param('id');
my $msg    = $input->param('msg');

my ( $template, $loggedinuser, $cookie ) = get_template_and_user(
    {   template_name   => "tools/upload.tt",
        query           => $input,
        type            => "intranet",
        authnotrequired => 0,
        flagsrequired   => { tools => 'upload_general_files' },
    }
);

$template->param(
    index      => $index,
    owner      => $loggedinuser,
    plugin     => $plugin,
    uploadcategories => Koha::UploadedFiles->getCategories,
);

if ( $op eq 'new' ) {
    $template->param(
        mode             => 'new',
    );
    output_html_with_http_headers $input, $cookie, $template->output;

} elsif ( $op eq 'search' ) {
    my $uploads;
    if( $id ) {
        my $rec = Koha::UploadedFiles->find( $id );
        undef $rec if $rec && $plugin && !$rec->public;
        push @$uploads, $rec->unblessed if $rec;
    } else {
        $uploads = Koha::UploadedFiles->search_term({
            term => $term,
            $plugin? (): ( include_private => 1 ),
        })->unblessed;
    }

    $template->param(
        mode    => 'report',
        msg     => $msg,
        uploads => $uploads,
    );
    output_html_with_http_headers $input, $cookie, $template->output;

} elsif ( $op eq 'delete' ) {
    # delete only takes the id parameter
    my $rec = Koha::UploadedFiles->find($id);
    undef $rec if $rec && $plugin && !$rec->public;
    my $fn = $rec ? $rec->filename : '';
    my $delete = $rec ? $rec->delete : undef;
    #TODO Improve error handling
    my $msg = $delete
        ? JSON::to_json({ $fn => 6 })
        : $id
        ? JSON::to_json({ $fn || $id, 7 })
        : '';
    $template->param(
        mode             => 'deleted',
        msg              => $msg,
    );
    output_html_with_http_headers $input, $cookie, $template->output;

} elsif ( $op eq 'download' ) {
    my $rec = Koha::UploadedFiles->find( $id );
    undef $rec if $rec && $plugin && !$rec->public;
    my $fh  = $rec? $rec->file_handle:  undef;
    if ( !$rec || !$fh ) {
        $template->param(
            mode             => 'new',
            msg              => JSON::to_json( { $id => 5 } ),
        );
        output_html_with_http_headers $input, $cookie, $template->output;
    } else {
        print Encode::encode_utf8( $input->header( $rec->httpheaders ) );
        while (<$fh>) {
            print $_;
        }
        $fh->close;
    }
}

==> koha-17.11.09.tar.gz: koha-17.11.09/tools/upload.pl <==
#!/usr/bin/perl

# This file is part of Koha.
#
# Copyright (C) 2015 Rijksmuseum
#
# Koha is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# Koha is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Koha; if not, see <http://www.gnu.org/licenses>.

use Modern::Perl;
use CGI qw/-utf8/;
use JSON;

use C4::Auth;
use C4::Output;
use Koha::UploadedFiles;

my $input  = CGI::->new;
my $op     = $input->param('op') // 'new';
my $plugin = $input->param('plugin');
my $index  = $input->param('index');         # MARC editor input field id
my $term   = $input->param('term');
my $id     = $input->param('id');
my $msg    = $input->param('msg');

my ( $template, $loggedinuser, $cookie ) = get_template_and_user(
    {   template_name   => "tools/upload.tt",
        query           => $input,
        type            => "intranet",
        authnotrequired => 0,
        flagsrequired   => { tools => 'upload_general_files' },
    }
);

$template->param(
    index      => $index,
    owner      => $loggedinuser,
    plugin     => $plugin,
    uploadcategories => Koha::UploadedFiles->getCategories,
);

if ( $op eq 'new' ) {
    $template->param(
        mode             => 'new',
    );
    output_html_with_http_headers $input, $cookie, $template->output;

} elsif ( $op eq 'search' ) {
    my $uploads;
    if( $id ) {
        my $rec = Koha::UploadedFiles->find( $id );
        undef $rec if $rec && $plugin && !$rec->public;
        push @$uploads, $rec->unblessed if $rec;
    } else {
        $uploads = Koha::UploadedFiles->search_term({
            term => $term,
            $plugin? (): ( include_private => 1 ),
        })->unblessed;
    }

    $template->param(
        mode    => 'report',
        msg     => $msg,
        uploads => $uploads,
    );
    output_html_with_http_headers $input, $cookie, $template->output;

} elsif ( $op eq 'delete' ) {
    # delete only takes the id parameter
    my $rec = Koha::UploadedFiles->find($id);
    undef $rec if $rec && $plugin && !$rec->public;
    my $fn = $rec ? $rec->filename : '';
    my $delete = $rec ? $rec->delete : undef;
    #TODO Improve error handling
    my $msg = $delete
        ? JSON::to_json({ $fn => { code => 6 }})
        : $id
        ? JSON::to_json({ $fn || $id, { code => 7 }})
        : '';
    $template->param(
        mode             => 'deleted',
        msg              => $msg,
    );
    output_html_with_http_headers $input, $cookie, $template->output;

} elsif ( $op eq 'download' ) {
    my $rec = Koha::UploadedFiles->find( $id );
    undef $rec if $rec && $plugin && !$rec->public;
    my $fh  = $rec? $rec->file_handle:  undef;
    if ( !$rec || !$fh ) {
        $template->param(
            mode             => 'new',
            msg              => JSON::to_json({ $id => { code => 5 }}),
        );
        output_html_with_http_headers $input, $cookie, $template->output;
    } else {
        print Encode::encode_utf8( $input->header( $rec->httpheaders ) );
        while (<$fh>) {
            print $_;
        }
        $fh->close;
    }
}
